package
Version:
v0.0.0-...-006b425
Opens a new window with list of versions in this module.
Published: Dec 22, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Product struct {
ID uint `gorm:"primary_key;auto_increment;not_null"`
Name string
FullPrice float64
Link string
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.