package
Version:
v0.0.0-...-006b425
Opens a new window with list of versions in this module.
Published: Dec 22, 2022
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func SendMessage(from, token, tel, msg string)
Send a WhatsApp message using the Zenvia API
type Contents struct {
Type string `json:"type"`
Text string `json:"text"`
}
type WhatsApp struct {
From string `json:"from"`
To string `json:"to"`
Contents []Contents `json:"contents"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.