Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetLowestPriceProd ¶
Returns the product with the lowest price in the slice of products
Types ¶
type ProdSelector ¶
type ProdSelector struct {
// contains filtered or unexported fields
}
func Selector ¶
func Selector() ProdSelector
Export ProductSelector to be used like a constant, carrying the selectors of the website
Click to show internal directories.
Click to hide internal directories.